@@ -56,10 +56,12 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Amanayé"                                       => "Amanaye",
    "Amatlán Zapotec"                               => "Amatlan Zapotec",
    "Anambé"                                        => "Anambe",
+   "Angaité"                                       => "Angaite",
    "Apalaí"                                        => "Apalai",
    "Apiaká"                                        => "Apiaka",
    "Apinayé"                                       => "Apinaye",
    "Apurinã"                                       => "Apurina",
+   "Ararandewára"                                  => "Ararandewara",
    "Araweté"                                       => "Arawete",
    "Arawá"                                         => "Arawa",
    "Arbëreshë Albanian"                            => "Arbereshe Albanian",
@@ -237,6 +239,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Lü"                                            => "Lu",
    "Macaguán"                                      => "Macaguan",
    "Magdalena Peñasco Mixtec"                      => "Magdalena Penasco Mixtec",
+   "Magɨyi"                                        => "Magyi",
    "Mainfränkisch"                                 => "Mainfrankisch",
    "Makuráp"                                       => "Makurap",
    "Maléku Jaíka"                                  => "Maleku Jaika",
@@ -477,6 +480,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Sîshëë"                                        => "Sishee",
    "Ménik"                                         => "Menik",
    "Nyelâyu"                                       => "Nyelayu",
+   "Yolŋu Sign Language"                           => "Yolnu Sign Language",
 };
 
 $Data{'language'}{'iana'}{'ignore'} = {
